@@ -1,6 +1,7 @@
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.db import models
+from django.db.models.signals import post_save
 from django.utils.translation import ugettext_lazy as _
 
 from oauth.oauth import OAuthToken
@@ -8,6 +9,7 @@ import simplejson
 import twitter
 
 from django_oauth_twitter.cache import DjangoCachedApi
+from django_oauth_twitter.signals import twitter_user_created
 from django_oauth_twitter.utils import fail_whale, get_user_info, TwitterApi
 
 
@@ -24,7 +26,7 @@ class TwitterUserManager(models.Manager):
     def _access_token(access_token, userinfo=None):
         if userinfo is None:
             userinfo = get_user_info(access_token)
-        attributes = {'access_token_str': access_token,
+        attributes = {'access_token_str': str(access_token),
                       'twitter_id': userinfo.id,
                       'userinfo_json': userinfo.AsJsonString()}
         return (attributes, userinfo)
@@ -84,16 +86,18 @@ class TwitterUser(models.Model):
     def __unicode__(self):
         return self.userinfo().screen_name
 
+    @classmethod
+    def on_create(cls, sender, instance, created, raw, **kwargs):
+        if created and not raw:
+            twitter_user_created.send(sender=cls, twitter_user=instance)
+
     def get_access_token(self):
         if self.access_token_str:
             return OAuthToken.from_string(self.access_token_str)
         return None
 
     def set_access_token(self, value):
-        if hasattr(value, 'to_string'):
-            self.access_token_str = value.to_string()
-        else:
-            self.access_token_str = value
+        self.access_token_str = str(value)
 
     access_token = property(get_access_token, set_access_token)
 
@@ -148,3 +152,5 @@ class TwitterUser(models.Model):
         return self.__class__.objects.filter(
             twitter_id__in=[f.id for f in followers]
         )
+
+post_save.connect(TwitterUser.on_create, sender=TwitterUser)
