@@ -114,6 +114,7 @@ class OAuthTwitter(object):
         Note: You must set this callback URL in Twitter's Application
         Details page.  Twitter ignores OAuth's oauth_callback option.
         """
+        @fail_whale
         def access_token(request_token):
             try:
                 return TwitterApi(request_token).getAccessToken()
@@ -130,7 +131,7 @@ class OAuthTwitter(object):
             remove_tokens(request)
             return self._redirect_to_login(request=request)
         # Save the access token in the session.
-        access_token = fail_whale(access_token)(request_token)
+        access_token = access_token(request_token)
         if isinstance(access_token, HttpResponse):
             return access_token
         set_access_token(request, access_token)
@@ -169,12 +170,13 @@ class OAuthTwitter(object):
 
     def signin(self, request):
         """Redirects a user to the Twitter authorization page."""
+        @fail_whale
         def get_signin_url(request):
             twitter = TwitterApi()
             request_token = twitter.getRequestToken()
             set_request_token(request, request_token)
             return twitter.getSigninURL(request_token)
-        return HttpResponseRedirect(fail_whale(get_signin_url)(request))
+        return HttpResponseRedirect(get_signin_url(request))
 
     def register(self, request,
                  template='django_oauth_twitter/register.html',
